@@ -6,9 +6,9 @@ import json
 from aiohttp.client_exceptions import ClientError
 
 from nonebot import get_driver
-from nonebot.params import State, ArgPlainText, Arg, CommandArg
+from nonebot.params import ArgPlainText, Arg, CommandArg
 from nonebot.plugin import on_command, on_message
-from nonebot.rule import to_me
+from nonebot.rule import to_me, Rule
 from nonebot.adapters.onebot.v11 import Bot, MessageEvent, GroupMessageEvent, PrivateMessageEvent, Message
 from nonebot.typing import T_State
 from nonebot.utils import DataclassEncoder
@@ -25,6 +25,7 @@ from .utils import limiter
 global_config = get_driver().config
 record_priority = getattr(global_config, "record_priority", 99)
 
+
 async def get_des(url: str, mode: str):
     """
     :param url: 图片链接
@@ -82,9 +83,9 @@ async def get_setu(bot: Bot,
                 async for msg in limiter(get_des(url, mod), getattr(bot.config, "search_limit", None) or 2):
                     await bot.send(event=event, message=msg)
             else:
-                msgs: Message = sum(
-                    [msg if isinstance(msg, Message) else Message(msg) async for msg in get_des(url, mod)])
-                dict_data = json.loads(json.dumps(msgs, cls=DataclassEncoder))
+                msgs = [msg if isinstance(msg, Message) else Message(msg) async for msg in get_des(url, mod)]
+                # msgs: Message = sum(msgs)
+                # dict_data = json.loads(json.dumps(msgs, cls=DataclassEncoder))
                 await bot.send_group_forward_msg(group_id=event.group_id,
                                                  messages=[
                                                      {
@@ -93,11 +94,12 @@ async def get_setu(bot: Bot,
                                                              "name": event.sender.nickname,
                                                              "uin": event.user_id,
                                                              "content": [
-                                                                 content
+                                                                 {"type": seg.type,
+                                                                  "data": seg.data}
                                                              ]
                                                          }
                                                      }
-                                                     for content in dict_data
+                                                     for msg in msgs for seg in msg
                                                  ]
                                                  )
 
@@ -113,7 +115,7 @@ async def get_setu(bot: Bot,
 pic_map: Dict[str, str] = {}  # 保存这个群的上一张色图 {"123456":"http://xxx"}
 
 
-async def check_pic(bot: Bot, event: MessageEvent, state: T_State = State()) -> bool:
+async def check_pic(bot: Bot, event: MessageEvent, state: T_State) -> bool:
     if isinstance(event, MessageEvent):
         for msg in event.message:
             if msg.type == "image":
@@ -127,7 +129,7 @@ notice_pic = on_message(check_pic, block=False, priority=record_priority)
 
 
 @notice_pic.handle()
-async def handle_pic(event: GroupMessageEvent, state: T_State = State()):
+async def handle_pic(event: GroupMessageEvent, state: T_State):
     try:
         group_id: str = str(event.group_id)
         pic_map.update({group_id: state["url"]})
@@ -149,7 +151,6 @@ async def handle_previous(bot: Bot, event: GroupMessageEvent):
         else:
             msgs: Message = sum(
                 [msg if isinstance(msg, Message) else Message(msg) async for msg in get_des(url, "nao")])
-            dict_data = json.loads(json.dumps(msgs, cls=DataclassEncoder))
             await bot.send_group_forward_msg(group_id=event.group_id,
                                              messages=[
                                                  {
@@ -158,11 +159,12 @@ async def handle_previous(bot: Bot, event: GroupMessageEvent):
                                                          "name": event.sender.nickname,
                                                          "uin": event.user_id,
                                                          "content": [
-                                                             content
+                                                             {"type": seg.type,
+                                                              "data": seg.data}
                                                          ]
                                                      }
                                                  }
-                                                 for content in dict_data
+                                                 for msg in msgs for seg in msg
                                              ]
                                              )
     except (IndexError, ClientError):
