@@ -12,10 +12,8 @@ from nonebot.adapters.onebot.v11 import MessageSegment
 from .formdata import FormData
 
 driver = nonebot.get_driver()
-if hasattr(driver.config, "ex_cookie"):
-    cookie: str = driver.config.ex_cookie
-if hasattr(driver.config, "proxy"):
-    proxy: str = driver.config.proxy
+cookie: str = getattr(driver.config, "ex_cookie", None)
+proxy: str = getattr(driver.config, "proxy", None)
 target: str = "https://exhentai.org/upload/image_lookup.php"
 
 headers = {
@@ -105,5 +103,4 @@ async def get_des(url: str):
         return
     for name, href, pic_url in image_data:
         content = await get_content_from_url(pic_url)
-        msg = MessageSegment.image(file=content) + f"\n本子名称：{name}\n" + f"链接{href}\n"
-        yield msg
+        yield MessageSegment.image(file=content) + f"\n本子名称：{name}\n" + f"链接{href}\n"
